pub struct Proxy { /* private fields */ }Expand description
A proxy to a remote object.
Acts as a client side proxy to an object existing in a remote pipewire instance. The proxy is responsible for converting interface functions invoked by the client to PipeWire messages. Events will call the callbacks registered in listeners.
Implementations
Sourceimpl Proxy
impl Proxy
pub fn add_listener_local(&self) -> ProxyListenerLocalBuilder<'_>
pub fn id(&self) -> u32
Sourcepub fn get_type(&self) -> (ObjectType, u32)
pub fn get_type(&self) -> (ObjectType, u32)
Get the type of the proxy as well as it’s version.